.. currentmodule:: sardana.tango.pool.TwoDExpChannel

:mod:`~sardana.tango.pool.TwoDExpChannel`
===========================================

.. automodule:: sardana.tango.pool.TwoDExpChannel

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`TwoDExpChannel`
    * :class:`TwoDExpChannelClass`

TwoDExpChannel
------------------

.. inheritance-diagram:: TwoDExpChannel
    :parts: 1
    
.. autoclass:: TwoDExpChannel
    :show-inheritance:
    :members:
    :undoc-members:

TwoDExpChannelClass
----------------------

.. inheritance-diagram:: TwoDExpChannelClass
    :parts: 1
    
.. autoclass:: TwoDExpChannelClass
    :show-inheritance:
    :members:
    :undoc-members:

